@@ -1,5 +1,5 @@
 #!/usr/bin/python3
-from common import models
+from sf_virtual_data.common import models as models
 import grpc
 from datetime import timedelta
 import re
