@@ -2,10 +2,10 @@
 from abc import ABC, abstractmethod
 from datetime import datetime, timedelta
 from . import solar_focus_sfv_lib as sofoc
-from common.models import VTCommandLineArgsBase
-from common.api import virtual_sfv_pb2
-from common.api import solar_field_common_pb2
-from common.api import common_models_pb2
+from sf_virtual_data.common.models import VTCommandLineArgsBase
+from sf_virtual_data.common.api import virtual_sfv_pb2
+from sf_virtual_data.common.api import solar_field_common_pb2
+from sf_virtual_data.common.api import common_models_pb2
 import google.protobuf.json_format as json_format
 from google.protobuf import wrappers_pb2
 from user_calculation import calculate as user_calc
